From: Richard Kennedy <richard@rsk.demon.co.uk>
To: James Morris <jmorris@namei.org>
Cc: sds@tycho.nsa.gov, lkml <linux-kernel@vger.kernel.org>
Subject: Re: [PATCH] selinux: reorder inode_security_struct to increase objs/slab on 64bit
Date: Mon, 19 May 2008 09:21:18 +0100 [thread overview]
Message-ID: <1211185278.2986.8.camel@castor.localdomain> (raw)
In-Reply-To: <Xine.LNX.4.64.0805190916290.12130@us.intercode.com.au>
On Mon, 2008-05-19 at 09:18 +1000, James Morris wrote:
> On Sun, 18 May 2008, Richard Kennedy wrote:
>
> > reorder inode_security_struct to remove padding on 64 bit builds
> >
> > size reduced from 72 to 64 bytes increasing objects per slab to 64.
> >
> > Signed-off-by: Richard Kennedy <richard@rsk.demon.co.uk>
>
> Thanks, applied to
> git://git.kernel.org/pub/scm/linux/kernel/git/jmorris/selinux-2.6.git#for-akpm
>
> (Although I see a reduction from 164 to 160 bytes).
>
>
> - James
In that case I think you've got all the lock & mutex debugging turned
on :)
CONFIG_DEBUG_MUTEXES & CONFIG_DEBUG_LOCK_ALLOC will add a lot to the
mutex directly.
CONFIG_GENERIC_LOCKBREAK, CONFIG_DEBUG_SPINLOCK &
CONFIG_DEBUG_LOCK_ALLOC will each grow the spinlock contained in the
mutex.
However, I'm seeing all structures packed to size of 8n -- so I'd never
get a sizeof 164. Maybe that's just a platform/compiler difference ?
I'm running on AMD 64 & gcc 4.1.2
Richard
next prev parent reply other threads:[~2008-05-19 8:30 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2008-05-18 11:32 Richard Kennedy
2008-05-18 23:18 ` James Morris
2008-05-19 8:21 ` Richard Kennedy [this message]
2008-05-19 11:39 ` Stephen Smalley
2008-05-20 0:01 ` James Morris
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1211185278.2986.8.camel@castor.localdomain \
--to=richard@rsk.demon.co.uk \
--cc=jmorris@namei.org \
--cc=linux-kernel@vger.kernel.org \
--cc=sds@tycho.nsa.gov \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®